Build table of dates with possible seroconversions in dataset
Source:R/build_omega_table.R
build_omega_table.RdBuild table of dates with possible seroconversions in dataset
Arguments
- participant_level_data
a data.frame with columns:
Stratum: indicator for which population stratum the participant belongs to
L: left censoring interval endpoint
R: right censoring interval endpoint
- bin_width
number of days per bin